@@ -27,8 +27,9 @@
 #include <string.h>
 #include <sys/stat.h>
 
+#include <glib/gi18n-lib.h>
+
 #include <libedataserver/e-data-server-util.h>
-#include <camel/camel-i18n.h>
 
 #include "camel-exchange-folder.h"
 #include "camel-exchange-search.h"
@@ -263,7 +264,8 @@ append_message_data (CamelFolder *folder, GByteArray *message,
 		stream_cache = camel_data_cache_add (exch->cache,
 						     "cache", new_uid, NULL);
 		if (stream_cache) {
-			camel_stream_write (stream_cache, message->data,
+			camel_stream_write (stream_cache,
+					    (char *) message->data,
 					    message->len);
 			camel_stream_flush (stream_cache);
 			camel_object_unref (CAMEL_OBJECT (stream_cache));
@@ -422,7 +424,7 @@ get_message_data (CamelFolder *folder, const char *uid, CamelException *ex)
 		return NULL;
 	}
 
-	camel_stream_write (stream, ba->data, ba->len);
+	camel_stream_write (stream, (char *) ba->data, ba->len);
 	camel_stream_flush (stream);
 	camel_object_unref (CAMEL_OBJECT (stream));
 
