@@ -25,7 +25,7 @@
 
 #include <string.h>
 
-#include <camel/camel-i18n.h>
+#include <glib/gi18n-lib.h>
 
 #include "camel-exchange-store.h"
 #include "camel-exchange-folder.h"
@@ -512,7 +512,7 @@ exchange_get_folder (CamelStore *store, const char *folder_name,
 		gchar *key;
 		g_mutex_lock (exch->folders_lock);
 		if (g_hash_table_lookup_extended (exch->folders, folder_name,
-						  (gpointer *) &key, NULL)) {
+						  (gpointer) &key, NULL)) {
 			g_hash_table_remove (exch->folders, key);
 			g_free (key);
 		}
@@ -535,10 +535,10 @@ exchange_get_folder (CamelStore *store, const char *folder_name,
 static gboolean
 exchange_folder_subscribed (CamelStore *store, const char *folder_name)
 {
-	d(printf ("is subscribed folder : %s\n", folder_name));
 	CamelExchangeStore *exch = CAMEL_EXCHANGE_STORE (store);
 	guint32 is_subscribed;
 	
+	d(printf ("is subscribed folder : %s\n", folder_name));
 	if (((CamelOfflineStore *) store)->state == CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL) {
 		return FALSE;
 	}
@@ -558,9 +558,9 @@ static void
 exchange_subscribe_folder (CamelStore *store, const char *folder_name,
 				CamelException *ex)
 {
-	d(printf ("subscribe folder : %s\n", folder_name));
 	CamelExchangeStore *exch = CAMEL_EXCHANGE_STORE (store);
 	
+	d(printf ("subscribe folder : %s\n", folder_name));
 	if (!camel_exchange_store_connected (exch, ex)) {
 		camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot subscribe folder in offline mode."));
 		return;
@@ -575,9 +575,9 @@ static void
 exchange_unsubscribe_folder (CamelStore *store, const char *folder_name,
 				CamelException *ex)
 {
-	d(printf ("unsubscribe folder : %s\n", folder_name));
 	CamelExchangeStore *exch = CAMEL_EXCHANGE_STORE (store);
 	
+	d(printf ("unsubscribe folder : %s\n", folder_name));
 	if (!camel_exchange_store_connected (exch, ex)) {
 		camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM, _("Cannot unsubscribe folder in offline mode."));
 		return;
@@ -612,13 +612,13 @@ static CamelFolderInfo *
 make_folder_info (CamelExchangeStore *exch, char *name, char *uri,
 		  int unread_count, int flags)
 {
-	d(printf ("make folder info : %s flags : %d\n", name, flags));
 	CamelFolderInfo *info;
 	const char *path;
 	gchar **components;
 	char *new_uri;
 	char *temp;
 
+	d(printf ("make folder info : %s flags : %d\n", name, flags));
 	path = strstr (uri, "://");
 	if (!path)
 		return NULL;
@@ -729,8 +729,14 @@ exchange_get_folder_info (CamelStore *store, const char *top, guint32 flags, Cam
 		store_flags |= CAMEL_STUB_STORE_FOLDER_INFO_RECURSIVE;
 	if (flags & CAMEL_STORE_FOLDER_INFO_SUBSCRIBED)
 		store_flags |= CAMEL_STUB_STORE_FOLDER_INFO_SUBSCRIBED;
+
+	/* CAMEL_STORE_FOLDER_INFO_FAST is called on only subscribed folders
+	   and the stub implementation checks for subscribed and recursive
+	   flags alone and hence, we need to OR SUBSCRIBED flag as well
+	 */
 	if (flags & CAMEL_STORE_FOLDER_INFO_FAST)
-		store_flags |= CAMEL_STUB_STORE_FOLDER_INFO_FAST;
+		store_flags |= (CAMEL_STUB_STORE_FOLDER_INFO_SUBSCRIBED | 
+				CAMEL_STUB_STORE_FOLDER_INFO_FAST);
 
 	if (!camel_stub_send (exch->stub, ex, CAMEL_STUB_CMD_GET_FOLDER_INFO,
 			      CAMEL_STUB_ARG_STRING, top,
